Things to read
==============

OAuth 2.0 Authorization Protocol - http://tools.ietf.org/html/rfc6749

OAuth 2.0 Bearer Tokens - http://tools.ietf.org/html/rfc6750


All different flavors:

* Yandex - http://api.yandex.ru/oauth/doc/dg/concepts/About.xml
* GitHub - https://developer.github.com/v3/oauth/
* Google - https://developers.google.com/accounts/docs/OAuth2
* Facebook - https://developers.facebook.com/docs/facebook-login/access-tokens